"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getApiFetch = void 0;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

// @ts-check

/**
 * Get a configured fetcher for API requests
 *
 * @param {{
 *   apiUrl: string
 *   getToken: () => string
 *   getOrgId: () => string
 *   permissionFailed: (res: Response) => string
 * }} spec
 * @returns {(pathname: string, opts?: RequestInit) => Promise}
 */
const getApiFetch = spec => (url, options = {}) => {
  const [path, passedQs] = url.split('?');
  const searchParams = new URLSearchParams(passedQs || '');
  searchParams.append('token', spec.getToken());
  return fetch(spec.apiUrl + path + '?' + searchParams.toString(), {
    method: options.method || 'get',
    headers: _objectSpread({
      'content-type': 'application/json'
    }, options.headers),
    body: options.body
  }).then(res => {
    if (res.status >= 400) {
      if (res.status === 404) {
        throw Error('NOT_FOUND');
      } else if (res.status === 403 || res.status === 401) {
        spec.permissionFailed(res);
      } else {
        throw Error('REQUEST_ERROR_' + res.status);
      }
    }

    return res.json();
  });
};

exports.getApiFetch = getApiFetch;